@@ -1,5 +1,5 @@
-setClass("distr", representation(x = "vector", name = "character", parameters = "numeric", sd = "numeric", 
-    n = "numeric", loglik = "numeric"))
+setClass("distr", representation(x = "vector", name = "character", parameters = "numeric", 
+    sd = "numeric", n = "numeric", loglik = "numeric"))
 setClass("distrCollection", representation(distr = "list"))
 setMethod("[", signature(x = "distrCollection", i = "ANY"), function(x, i, drop = missing) {
     x@distr[i]
@@ -48,8 +48,8 @@ distribution = function(x, distribution = "weibull", start, ...) {
         stop("Package MASS needs to be installed!")
     if (is.character(distribution)) 
         distribution = tolower(distribution)
-    allDistr = c("beta", "cauchy", "chi-squared", "exponential", "f", "gamma", "geometric", "log-normal", "logistic", 
-        "negative binomial", "normal", "poisson", "t", "weibull")
+    allDistr = c("beta", "cauchy", "chi-squared", "exponential", "f", "gamma", "geometric", "log-normal", 
+        "logistic", "negative binomial", "normal", "poisson", "t", "weibull")
     if (distribution %in% allDistr) 
         distrVec = distribution
     else distrVec = c("normal")
@@ -71,8 +71,8 @@ distribution = function(x, distribution = "weibull", start, ...) {
     return(distrColl)
 }
 setGeneric("plot", function(x, y, ...) standardGeneric("plot"))
-setMethod("plot", signature(x = "distr"), function(x, y, main, xlab, xlim, ylim, ylab, line.col, line.width, 
-    box = TRUE, ...) {
+setMethod("plot", signature(x = "distr"), function(x, y, main, xlab, xlim, ylim, ylab, 
+    line.col, line.width, box = TRUE, ...) {
     object = x
     xVals = object@x
     parameters = object@parameters
@@ -116,8 +116,8 @@ setMethod("plot", signature(x = "distr"), function(x, y, main, xlab, xlim, ylim,
     hist(xVals, freq = FALSE, xlab = xlab, ylab = ylab, xlim = xlim, ylim = ylim, main = main, ...)
     lines(xPoints, yPoints, col = line.col, lwd = line.width)
     abline(h = 0)
-    legend("topright", c(paste(c(names(parameters), "A", "p"), ": ", c(format(parameters, digits = 3), format(A, digits = 3), 
-        format(p, digits = 3))), sep = " "), inset = 0.02)
+    legend("topright", c(paste(c(names(parameters), "A", "p"), ": ", c(format(parameters, digits = 3), 
+        format(A, digits = 3), format(p, digits = 3))), sep = " "), inset = 0.02)
     if (box) {
         box()
     }
@@ -143,8 +143,8 @@ setMethod("plot", signature(x = "distr"), function(x, y, main, xlab, xlim, ylim,
     invisible(list(xlim = x, ylim = y))
 }
 setGeneric("plot", function(x, y, ...) standardGeneric("plot"))
-setMethod("plot", signature(x = "distrCollection"), function(x, y, xlab, ylab, xlim, ylim, line.col, line.width, 
-    ...) {
+setMethod("plot", signature(x = "distrCollection"), function(x, y, xlab, ylab, xlim, ylim, 
+    line.col, line.width, ...) {
     y = NULL
     object = x
     distrList = object@distr
@@ -158,7 +158,8 @@ setMethod("plot", signature(x = "distrCollection"), function(x, y, xlab, ylab, x
         line.col = "red"
     if (missing(line.width)) 
         line.width = 1
-    lapply(distrList, plot, xlim = xlim, ylim = ylim, line.col = line.col, line.width = line.width, ...)
+    lapply(distrList, plot, xlim = xlim, ylim = ylim, line.col = line.col, line.width = line.width, 
+        ...)
     cat(paste("Total of", numDist, "plots created"))
     cat("\n")
     cat(paste("Use par(mfrow = c(2,", numColWin, ") to see all of them!", sep = ""))
@@ -201,8 +202,8 @@ qqPlot = function(x, y, main, xlab, ylab, xlim, ylim, border = "red", start, ...
     theoretical.quantiles = NULL
     xs = sort(x)
     distribution = tolower(y)
-    distWhichNeedParameters = c("weibull", "logistic", "gamma", "exponential", "f", "geometric", "chi-squared", "negative binomial", 
-        "poisson")
+    distWhichNeedParameters = c("weibull", "logistic", "gamma", "exponential", "f", "geometric", 
+        "chi-squared", "negative binomial", "poisson")
     if (is.character(distribution)) {
         qFun = .charToDistFunc(distribution, type = "q")
         if (is.null(qFun)) 
@@ -268,8 +269,8 @@ qqPlot = function(x, y, main, xlab, ylab, xlim, ylim, border = "red", start, ...
     do.call(abline, params)
     invisible(list(x = theoretical.quantiles, y = xs, int = params$a, slope = params$b))
 }
-ppPlot = function(x, distribution, probs, main, xlab, ylab, xlim, ylim, border = "red", grid = TRUE, box = TRUE, 
-    stats = TRUE, start, ...) {
+ppPlot = function(x, distribution, probs, main, xlab, ylab, xlim, ylim, border = "red", 
+    grid = TRUE, box = TRUE, stats = TRUE, start, ...) {
     DB = FALSE
     conf.level = 0.95
     conf.lines = TRUE
@@ -320,8 +321,8 @@ ppPlot = function(x, distribution, probs, main, xlab, ylab, xlim, ylim, border =
         }
         invisible()
     }
-    distWhichNeedParameters = c("weibull", "gamma", "logistic", "exponential", "f", "geometric", "chi-squared", "negative binomial", 
-        "poisson")
+    distWhichNeedParameters = c("weibull", "gamma", "logistic", "exponential", "f", "geometric", 
+        "chi-squared", "negative binomial", "poisson")
     if (is.character(distribution)) {
         qFun = .charToDistFunc(distribution, type = "q")
         pFun = .charToDistFunc(distribution, type = "p")
