@@ -1,4 +1,5 @@
-dotPlot = function(x, group, xlim, ylim, col, xlab, ylab, pch, cex, breaks, stacked = TRUE, ...) {
+dotPlot = function(x, group, xlim, ylim, col, xlab, ylab, pch, cex, breaks, stacked = TRUE, 
+    ...) {
     DB = FALSE
     pch.size = "O"
     grouped = TRUE
@@ -99,8 +100,8 @@ dotPlot = function(x, group, xlim, ylim, col, xlab, ylab, pch, cex, breaks, stac
     if (grouped && !stacked) {
         groupIndex = unique(group)
         par(mfrow = c(length(groupIndex), 1))
-        for (i in groupIndex) dotPlot(x[group == i], xlim = xlim, breaks = breaks, cex = cex, xlab = xlab, ylab = ylab, 
-            col = col, pch = pch, ...)
+        for (i in groupIndex) dotPlot(x[group == i], xlim = xlim, breaks = breaks, cex = cex, xlab = xlab, 
+            ylab = ylab, col = col, pch = pch, ...)
     }
     else {
         mat = mat[1:cutOff, ]
