@@ -1,25 +1,30 @@
 fracChoose = function() {
     DB = FALSE
     genList = list(6 * 9)
-    genList = list(c("C = AB"), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c("D = ABC"), 
-        c("D = AB", "E = AC"), c("D = AB", "E = AC", "F = BC"), c("D = AB", "E = AC", "F = BC", "G = ABC"), c(NULL), c(NULL), 
-        c(NULL), c(NULL), c(NULL), c(NULL), c("E = ABCD"), c("E = ABC", "F = BCD"), c("E = ABC", "F = BCD", "G = ACD"), 
-        c("E = BCD", "F = ACD", "G = ABC", "H = ABD"), c("E = ABC", "F = BCD", "G = ACD", "H = ABD", "J = ABCD"), c("E = ABC", 
-            "F = BCD", "G = ACD", "H = ABD", "J = ABCD", "K = AB"), c("E = ABC", "F = BCD", "G = ACD", "H = ABD", "J = ABCD", 
-            "K = AB", "L = AC"), c(NULL), c(NULL), c(NULL), c("F = ABCDE"), c("F = ABCD", "G = ABDE"), c("F = ABC", "G = ABD", 
-            "H = BCDE"), c("F = BCDE", "G = ACDE", "H = ABDE", "J = ABCE"), c("F = ABCD", "G = ABCE", "H = ABDE", "J = ACDE", 
-            "K = BCDE"), c("F = ABC", "G = BCD", "H = CDE", "J = ACD", "K = AEF", "L = ADEF"), c(NULL), c(NULL), c(NULL), 
-        c(NULL), c("G = ABCDEF"), c("G = ABCD", "H = ABEF"), c("G = ABCD", "H = ACEF", "J = CDEF"), c("G = BCDF", "H = ACDF", 
-            "J = ABDE", "K = ABCE"), c("G = CDE", "H = ABCD", "J = ABF", "K = BDEF", "L = ADEF"), c(NULL), c(NULL), c(NULL), 
-        c(NULL), c(NULL), c("H = ABCDEFG"), c("H = ACDFG", "J = BCEFG"), c("H = ABCG", "J = BCDE", "K = ACDF"), c("H = ABCG", 
-            "J = BCDE", "K = ACDF", "L = ABCDEFG"))
+    genList = list(c("C = AB"), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), 
+        c(NULL), c("D = ABC"), c("D = AB", "E = AC"), c("D = AB", "E = AC", "F = BC"), c("D = AB", 
+            "E = AC", "F = BC", "G = ABC"), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), 
+        c("E = ABCD"), c("E = ABC", "F = BCD"), c("E = ABC", "F = BCD", "G = ACD"), c("E = BCD", 
+            "F = ACD", "G = ABC", "H = ABD"), c("E = ABC", "F = BCD", "G = ACD", "H = ABD", "J = ABCD"), 
+        c("E = ABC", "F = BCD", "G = ACD", "H = ABD", "J = ABCD", "K = AB"), c("E = ABC", "F = BCD", 
+            "G = ACD", "H = ABD", "J = ABCD", "K = AB", "L = AC"), c(NULL), c(NULL), c(NULL), c("F = ABCDE"), 
+        c("F = ABCD", "G = ABDE"), c("F = ABC", "G = ABD", "H = BCDE"), c("F = BCDE", "G = ACDE", 
+            "H = ABDE", "J = ABCE"), c("F = ABCD", "G = ABCE", "H = ABDE", "J = ACDE", "K = BCDE"), 
+        c("F = ABC", "G = BCD", "H = CDE", "J = ACD", "K = AEF", "L = ADEF"), c(NULL), c(NULL), c(NULL), 
+        c(NULL), c("G = ABCDEF"), c("G = ABCD", "H = ABEF"), c("G = ABCD", "H = ACEF", "J = CDEF"), 
+        c("G = BCDF", "H = ACDF", "J = ABDE", "K = ABCE"), c("G = CDE", "H = ABCD", "J = ABF", "K = BDEF", 
+            "L = ADEF"), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c("H = ABCDEFG"), c("H = ACDFG", 
+            "J = BCEFG"), c("H = ABCG", "J = BCDE", "K = ACDF"), c("H = ABCG", "J = BCDE", "K = ACDF", 
+            "L = ABCDEFG"))
     resList = list(6 * 9)
-    resList = list(c(3), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(4), c(3), 
-        c(3), c(3), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(5), c(4), c(4), c(4), c(3), c(3), c(3), c(NULL), 
-        c(NULL), c(NULL), c(6), c(4), c(4), c(4), c(4), c(4), c(NULL), c(NULL), c(NULL), c(NULL), c(7), c(5), c(4), c(4), 
-        c(4), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(8), c(6), c(5), c(5))
+    resList = list(c(3), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), 
+        c(NULL), c(4), c(3), c(3), c(3), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(NULL), c(5), 
+        c(4), c(4), c(4), c(3), c(3), c(3), c(NULL), c(NULL), c(NULL), c(6), c(4), c(4), c(4), c(4), 
+        c(4), c(NULL), c(NULL), c(NULL), c(NULL), c(7), c(5), c(4), c(4), c(4), c(NULL), c(NULL), 
+        c(NULL), c(NULL), c(NULL), c(8), c(6), c(5), c(5))
     facMat = matrix(rep(3:11, 6), ncol = 9, byrow = TRUE)
-    runMat = matrix(c(rep(2^2, 9), rep(2^3, 9), rep(2^4, 9), rep(2^5, 9), rep(2^6, 9), rep(2^7, 9)), ncol = 9, byrow = TRUE)
+    runMat = matrix(c(rep(2^2, 9), rep(2^3, 9), rep(2^4, 9), rep(2^5, 9), rep(2^6, 9), rep(2^7, 9)), 
+        ncol = 9, byrow = TRUE)
     par(mfrow = c(6, 9))
     par(mar = c(0, 0, 0, 0))
     par(oma = c(4, 4, 4, 4))
@@ -35,8 +40,8 @@ fracChoose = function() {
     m = 0
     for (i in seq(along = genList)) {
         res = unlist(resList[[i]])
-        plot(0, 0, xaxs = "i", yaxs = "i", xlim = c(0, 1), ylim = c(0, 1), axes = FALSE, type = "n", xlab = "", ylab = "", 
-            bg = "red", fg = "green")
+        plot(0, 0, xaxs = "i", yaxs = "i", xlim = c(0, 1), ylim = c(0, 1), axes = FALSE, type = "n", 
+            xlab = "", ylab = "", bg = "red", fg = "green")
         box()
         if (!is.null(res)) 
             rect(0, 0, 1, 1, col = colList[[res]])
@@ -49,8 +54,8 @@ fracChoose = function() {
         p = log2((2^k)/N)
         if (!is.null(res)) {
             romNum = as.character(as.roman(res))
-            text(0.1, 0.9, do.call("expression", list(substitute(2[romNum]^(k - p), list(k = k, p = p, romNum = romNum)))), 
-                adj = c(0, 1), cex = 1.5)
+            text(0.1, 0.9, do.call("expression", list(substitute(2[romNum]^(k - p), list(k = k, p = p, 
+                romNum = romNum)))), adj = c(0, 1), cex = 1.5)
         }
         k = k + 1
         if ((i%%9) == 0) {
